@@ -6,7 +6,7 @@ from ..common.graphql import GraphqlClient
 import time
 
 
-class ManagementTokenProvider():
+class ManagementTokenProvider:
     def __init__(self, options, graphqlClient):
         # type:(ManagementClientOptions,GraphqlClient) -> ManagementTokenProvider
         self.options = options
@@ -16,12 +16,15 @@ class ManagementTokenProvider():
         self._accessTokenExpriredAt = None
 
     def _getClientWhenSdkInit(self):
-        res = self.graphqlClient.request(query=QUERY["accessToken"], params={
-            "userPoolId": self.options.user_pool_id,
-            "secret": self.options.secret
-        })
-        data = res['accessToken']
-        accessToken, iat, exp = data['accessToken'], data['iat'], data['exp']
+        res = self.graphqlClient.request(
+            query=QUERY["accessToken"],
+            params={
+                "userPoolId": self.options.user_pool_id,
+                "secret": self.options.secret,
+            },
+        )
+        data = res["accessToken"]
+        accessToken, iat, exp = data["accessToken"], data["iat"], data["exp"]
         return accessToken, iat, exp
 
     def getAccessToken(self):
